%define major		3
%define libname		%mklibname myguiengine %{major}
%define devname		%mklibname myguiengine -d

%global __requires_exclude	devel\\(libMyGUI.OgrePlatform

Name:           mygui
Version:        3.2.1
Release:        %mkrel 4
Summary:        Fast, simple and flexible GUI library for Ogre
Group:          Development/Other
# UnitTests include agg-2.4, which is under a BSD variant (not built or installed here)
License:        MIT
URL:            http://mygui.info/
Source0:        https://github.com/MyGUI/mygui/archive/MyGUI%{version}.tar.gz
# Helper to run demos, based on A. Torkhov Ogre-Samples shipped with ogre-samples
Source1:        MyGUI-Demos
# Another helper for the tools
Source2:        MyGUI-Tools
# Demo and tools resources configuration
Source3:        resources.xml
# LayoutEditor desktop entry
Source4:        mygui-layouteditor.desktop
# Fix multilib and flags with cmake
Patch0:         mygui_multilib_cflags.patch
# Fixup libCommon
Patch1:		mygui-libCommon-fixup.patch
# Fix linking
Patch2:		mygui-linking.patch
# fix build with gcc 4.7 (from SUSE)
Patch3:		mygui-gcc47-visibility.patch
# from gentoo
Patch4:		mygui-3.2.1-FHS.patch
BuildRequires:	freetype-devel
BuildRequires:  ois-devel
BuildRequires:	ogre-devel
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	cmake
BuildRequires:	dos2unix
BuildRequires:  libuuid-devel
Requires:       fonts-ttf-dejavu
Requires:       %{libname} >= %{version}-%{release}

%description
MyGUI is a GUI library for Ogre Rendering Engine which aims to be fast,
flexible and simple in using.

%package -n %{libname}
Summary:	Shared libraries for MyGUI
Group:		System/Libraries

%description -n %{libname}
MyGUI is a GUI library for Ogre Rendering Engine which aims to be fast,
flexible and simple in using.

%package -n %{devname}
Summary:        Development files for MyGUI
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the development files and headers for MyGUI.

%package demos
Summary:        MyGUI demo executables and media
Group:          Development/Other
Requires:	%{name} = %{version}-%{release}

%description demos
This package contains the compiled (not the source) sample applications coming
with MyGUI. It also contains some media (meshes, textures,...) needed by these
samples. The samples are installed in %{_libdir}/MYGUI/Demos, and an helper
script MyGUI-Demos is provided and installed in %{_bindir}.

%package tools
Summary:        MyGUI tools
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}

%description tools
This package contains the MyGUI tools, installed in %{_libdir}/MYGUI/Tools.
LayoutEditor is an application for designing UIs using MyGUI library,
ImageSetViewer and FontViewer are simple tools to preview graphical
resources in the media repository.

An helper script MyGUI-Tools is provided and installed in %{_bindir}.

%package docs
Summary:	Documentation for MyGUI
Group:		Documentation

%description docs
This package contains the development documentation for MyGUI.

%prep
%setup -qn mygui-MyGUI%{version}
%patch0 -p0 -b .multilib
%patch1 -p1 -b .fixup
%patch2 -p1 -b .linking
%patch3 -p1 -b .visibility
%patch4 -p0 -b .FHS

# Fix non-UTF8 files
dos2unix Tools/LayoutEditor/Readme.txt
iconv -f ISO-8859-1 -t UTF-8 -o Tools/LayoutEditor/Readme.txt.UTF-8 \
	Tools/LayoutEditor/Readme.txt
mv -f Tools/LayoutEditor/Readme.txt.UTF-8 Tools/LayoutEditor/Readme.txt

# Generate README for -tools and -demos
cat > Tools/README << EOT
This package contains the MyGUI tools: ImageEditor, FontEditor,
SkinEditor and LayoutEditor; to run the tools, launch the helper
script %{_bindir}/MyGUI-Tools
EOT

cat > Demos/README << EOT
This package contains MyGUI demos; to run the demos, launch the
helper script %{_bindir}/MyGUI-Demos
EOT

%build
# Plugins are windows only atm
%cmake \
       	-DCMAKE_SKIP_RPATH=TRUE \
	-DMYGUI_STATIC=FALSE \
        -DMYGUI_BUILD_PLUGINS=FALSE
%make

# Generate doxygen documentation
pushd Docs
	doxygen
	rm -f html/installdox
popd

%install
%makeinstall_std -C build

# we don't want these
find %{buildroot} -name '*.la' -delete

# Remove binaries installed in %%{_bindir}
rm -rf %{buildroot}/%{_bindir}/

# Create config for ldconfig
mkdir -p %{buildroot}/etc/ld.so.conf.d
echo "%{_libdir}/MYGUI" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf

# Install the samples
mkdir -p %{buildroot}%{_libdir}/MYGUI/Demos
cp -p %{SOURCE3} build/bin/plugins.cfg %{buildroot}%{_libdir}/MYGUI/Demos
sed -i 's|^PluginFolder=.*$|PluginFolder=%{_libdir}/OGRE|' \
    %{buildroot}%{_libdir}/MYGUI/Demos/plugins.cfg
sed -i 's|^Plugin=RenderSystem_Direct3D9$|#Plugin=RenderSystem_Direct3D9|' \
    %{buildroot}%{_libdir}/MYGUI/Demos/plugins.cfg
for file in build/bin/Demo_* ; do
  install -Dp -m 755 $file %{buildroot}%{_libdir}/MYGUI/Demos/`basename $file`
done
mkdir -p %{buildroot}%{_bindir}
install -Dp -m 755 %{SOURCE1} %{buildroot}%{_bindir}/

# Install the tools
mkdir -p %{buildroot}%{_libdir}/MYGUI/Tools
cp -p %{SOURCE3} build/bin/plugins.cfg %{buildroot}%{_libdir}/MYGUI/Tools
sed -i 's|^PluginFolder=.*$|PluginFolder=%{_libdir}/OGRE|' \
    %{buildroot}%{_libdir}/MYGUI/Tools/plugins.cfg
sed -i 's|^Plugin=RenderSystem_Direct3D9$|#Plugin=RenderSystem_Direct3D9|' \
    %{buildroot}%{_libdir}/MYGUI/Tools/plugins.cfg
for file in build/bin/SkinEditor build/bin/LayoutEditor build/bin/ImageEditor build/bin/FontEditor ; do
  install -Dp -m 755 $file %{buildroot}%{_libdir}/MYGUI/Tools/`basename $file`
done
install -Dp -m 755 %{SOURCE2} %{buildroot}%{_bindir}/

# Install desktop entry for LayoutEditor
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE4}

# Copy Media files
mkdir -p %{buildroot}%{_datadir}/MyGUI/
cp -a Media %{buildroot}%{_datadir}/MyGUI/

# Move libMyGUI.OgrePlatform.so
mv %{buildroot}%{_libdir}/libMyGUI.OgrePlatform.so %{buildroot}%{_libdir}/MYGUI/

# Move plugins to %{libdir}/MYGUI (no plugins atm)
#mv %{buildroot}%{_libdir}/libPlugin*.so %{buildroot}%{_libdir}/MYGUI

# Strip away code in media dir
#rm -rf %{buildroot}%{_datadir}/MyGUI/Media/Tools/LayoutEditor/CodeTemplates/

# Strip away unittests media
rm -rf %{buildroot}%{_datadir}/MyGUI/Media/UnitTests

# Remove CMake stuff from Media
rm -f %{buildroot}%{_datadir}/MyGUI/Media/CMakeLists.txt

# Link fonts from dejavu package
ln -fs %{_datadir}/fonts/TTF/dejavu/DejaVuSans.ttf \
	%{buildroot}%{_datadir}/MyGUI/Media/MyGUI_Media/DejaVuSans.ttf
ln -fs %{_datadir}/fonts/TTF/dejavu/DejaVuSans-ExtraLight.ttf \
	%{buildroot}%{_datadir}/MyGUI/Media/MyGUI_Media/DejaVuSans-ExtraLight.ttf

# CMake hurts my brain.
cp -a build/%{_lib}/libCommon.so* %{buildroot}%{_libdir}/

%files
%dir %{_datadir}/MyGUI/
%dir %{_datadir}/MyGUI/Media/
%{_datadir}/MyGUI/Media/Common/
%{_datadir}/MyGUI/Media/MyGUI_Media/

%files -n %{libname}
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%dir %{_libdir}/MYGUI/
%{_libdir}/MYGUI/libMyGUI.OgrePlatform.so
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files -n %{devname}
%{_includedir}/MYGUI/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files demos
%doc Demos/README
%{_bindir}/MyGUI-Demos
%{_libdir}/MYGUI/Demos
%{_datadir}/MyGUI/Media/Demos
%{_datadir}/MyGUI/Media/Wrapper

%files tools
%doc Tools/README
%doc Tools/LayoutEditor/Readme.txt
%{_bindir}/MyGUI-Tools
%{_libdir}/MYGUI/Tools
%{_datadir}/MyGUI/Media/Tools
%{_datadir}/applications/mygui-layouteditor.desktop

%files docs
%doc build/Docs/html/


%changelog
* Wed Oct 15 2014 umeabot <umeabot> 3.2.1-4.mga5
+ Revision: 751146
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.2.1-3.mga5
+ Revision: 727423
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.2.1-2.mga5
+ Revision: 682720
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes

* Mon Aug 25 2014 wally <wally> 3.2.1-1.mga5
+ Revision: 667383
- new version 3.2.1
- upstream changed license to MIT
- rediff patches and add file location patch from Gentoo

* Mon Mar 31 2014 akien <akien> 3.2.0-8.mga5
+ Revision: 610916
- Rebuild for new OGRE

* Wed Feb 05 2014 wally <wally> 3.2.0-6.mga5
+ Revision: 583684
- rebuild for new boost

* Sat Oct 19 2013 umeabot <umeabot> 3.2.0-5.mga4
+ Revision: 531645
- Mageia 4 Mass Rebuild

* Wed Aug 07 2013 wally <wally> 3.2.0-4.mga4
+ Revision: 464404
- fix wrapper scripts after behavior change in findutils 4.5.11

* Wed Aug 07 2013 wally <wally> 3.2.0-3.mga4
+ Revision: 464385
- fix font symlinks

* Wed Aug 07 2013 wally <wally> 3.2.0-2.mga4
+ Revision: 464370
- make main pkg to require libs
- add requires exceptions for devel pkg
- add common provides to devel pkg

* Wed Aug 07 2013 wally <wally> 3.2.0-1.mga4
+ Revision: 464359
- import MyGUI (based on .spec and patches from Fedora)
- add patch to fix build with gcc 4.7 (from SUSE)
- add patch to fix linking

